Node-Broker
===========

Subscriber and Publisher do not know about each other; they only know Node-Broker. It's like a cross-module messaging and processing system.

Installation
------------
    
    npm install broker

Justification
-------------

Since commands are available everywhere, the broker can be seen as a global command center. Why should you ever want to do this? The simple reason is because it allows you to create modules that simply provide and require data from the broker, meaning that any other module can work with the original module by simply providing the required commands to the broker.

Example 1
---------

### Module1.js

    var broker = require('broker');
    
    broker.handle('getAppName', function(cb) {
        cb('BrokerTest');
    });

### Module2.js

    var broker = require('broker');
    
    broker.exec('getAppName', function(name) {
        require('util').debug('app name is ' + name);
    });
    
__Note:__ a handle must be set before it is attempted to be executed, or an error will be thrown.

Example 2
---------

See https://github.com/tommedema/node-broker/tree/master/examples/simple for a simple example.

Namespacing
-----------

You are responsible for your own namespacing, this can be done by simply prefixing your command with a namespace:
    
    broker.handle('chat#remClient', function(name) { });
    
And to execute it:
    
    broker.exec('chat#remClient', 'Tom');
    
The above example uses the remClient command in the chat namespace. Note that this command can still be used anywhere, it simply needs to be prefixed with the namespace.